@@ -4,7 +4,9 @@ setwd(tempdir())
 
 ## process html -- should work everywhere
 ## but doesn't: CRAN's macOS and Solaris have seriously outdated pandoc binaries
-if (isTRUE(unname(Sys.info()["sysname"]) %in% c("Linux","Windows"))) {
+## replace with test from rmarkdown itself
+## old: asTRUE(unname(Sys.info()["sysname"]) %in% c("Linux","Windows"))) {
+if (rmarkdown::pandoc_available("1.12.3")) {
     file.copy(system.file("examples", "simpleHtml.Rmd", package="tint"), "simpleHtml.Rmd")
     rmarkdown::render("simpleHtml.Rmd")
 }
